#
# spec file for package gnome-chess
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-chess
Version:        43.2
Release:        1.2
Summary:        Chess Game for GNOME
License:        GPL-3.0-or-later
Group:          Amusements/Games/Board/Chess
URL:            https://wiki.gnome.org/Apps/Chess
Source0:        https://download.gnome.org/sources/gnome-chess/43/%{name}-%{version}.tar.xz

BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
# ITS Tool is needed because there are some XML formats that Gettext does not handle, at least not now (42.alpha).
BuildRequires:  itstool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.35.7
BuildRequires:  pkgconfig(gio-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.44.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gtk4) >= 3.19.0
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.32.0
Requires:       chess_backend

%description
This is a game for playing the classic board game of chess, in which
two players simulate a battle by capturing the opponents pieces and
ultimately the king. It can be played in 2D or 3D mode, full screen or
in a window.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/*.desktop

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_datadir}/icons/hicolor/
%{_bindir}/%{name}
%dir %{_datadir}/metainfo
%{_datadir}/applications/org.gnome.Chess.desktop
%{_datadir}/dbus-1/services/org.gnome.Chess.service
%{_datadir}/glib-2.0/schemas/org.gnome.Chess.gschema.xml
%{_datadir}/metainfo/org.gnome.Chess.appdata.xml
%{_mandir}/man6/%{name}.6%{?ext_man}
%dir %{_sysconfdir}/gnome-chess
%config %{_sysconfdir}/gnome-chess/engines.conf

%files lang -f %{name}.lang

%changelog
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.2:
  + Help: Remove references to mailing lists.
  + Updated translations.
* Thu Jan  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Fix build with latest valac.
  + Fix keyboard shortcuts dialog.
  + Updated translations.
* Thu Sep 15 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated application screenshot.
  + Updated translations.
- Add desktop-file-utils BuildRequires: New dependency.
- Following the above new BuildRequires, add a check section and
  verify desktop file during build.
* Thu Sep  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.rc:
  + New preferences dialog and new game screen.
  + Updated translations.
* Wed Aug 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.1:
  + Use pango to render clock text, fixing broken ratio and LTR
    characters.
  + Updated translations.
* Fri Mar 18 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 42.0:
  + Updated translations.
* Fri Jan  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.alpha:
  + Use libadwaita.
- Add pkgconfig(libadwaita-1) BuildRequires, new dependency.
* Fri Oct 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + Fix Exec= line in desktop file.
* Fri Sep 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.0:
  + Several updates to user help.
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.1:
  + Update user help.
  + Add workaround for engine taking too long to move.
  + Fix autosaved game being deleted when window is not closed
    with Ctrl+Q.
  + Fix invalid signal ID warning when starting a new game.
* Tue Mar 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Update icon in user help.
  + Updated translations
* Mon Jan 11 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Port to GTK 4.
  + Major refactoring of portions of the UI layer. Split engine
    code into separate layer.
  + Rework promotion type selector to avoid GTK warnings.
  + Hide timers in untimed games.
  + Custom PGN tags are now prefixed with X-GNOME.
  + Promotion type selector now fits screen in narrow mode.
  + Use info bar, not header bar subtitle, to display extra status
    messages.
  + Reduce length of Oops! message in header bar on engine error.
  + Improve message when game ends in stalemate.
  + Move New Game from header bar to primary menu to save space.
  + Rename Save to Save As, and display a separate Save action.
- Replace pkgconfig(gtk+-3.0) BuildRequires with pkgconfig(gtk4):
  Follow upstreams port to GTK 4.
* Mon Dec  7 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.1:
  + Try to make all chess engines easier on Easy and Normal
    difficulty.
  + Fix claim draw dialog appearing every turn after threefold
    repetition.
  + Fix bogus "computer player is confused" errors in several
    situations:
  - When the engine is stalemated.
  - When starting a new game while the game is paused, if the
    engine has moved during pause.
  - When resigning immediately before the engine moves.
  + Fix file chooser defaulting to /run when game is saved for a
    second time under flatpak.
  + Fix detection of stalled chess engine in untimed games.
  + Fix claim draw dialog appearing before a forced draw.
  + Fix ChessScene removing invalid GSource.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.3:
  + Fix timed games opening as untimed games.
  + Various refactoring and preparation for GTK 4.
- Changes from version 3.37.2:
  + Make easy mode vs. GNU Chess a bit easier.
  + Support D-Bus activation.
- Changes from version 3.37.1.1::
  + Fix previous tag.
- Changes from version 3.37.1:
  + Various refactoring and preparation for GTK 4.
  + Improve keyboard shortcuts dialog.
  + Updated translations.
* Thu Jun  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Fix window switching to narrow mode when opening menu.
* Fri Mar  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.3:
  + Move open, save, and resign game buttons into window menu.
  + Improve display for small screen sizes.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Mon Sep  2 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.33.90:
  + Fix build with latest vala.
  + Updated translations.
- Drop ancient glchess and glchess-lang Obsoletes as well as
  glchess Provides: No longer needed.
- Use autosetup macro.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Mon Mar  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Add padding to bottom row of widgets.
  + Updates to user help.
* Sun Feb 17 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Fix "computer player is confused" when CECP engine claims a
    draw.
  + Reworded claim draw dialog to reduce confusion when engine
    claims draw.
  + Fixed zombie engine processes not being properly reaped.
  + New icon!
  + Change app ID to org.gnome.Chess.
* Sat Feb  9 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Replace app menu with window menu.
  + Rewrite the user help.
  + Updated translations.
* Fri Feb  8 2019 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Fix "computer player is confused" when CECP engine claims a
    draw.
* Sat Sep  8 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
- Remove lang package from recommended packages as it already
  supplements main package (same effect, it's redundant).
* Sat Jul 28 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Fix code to ensure chess engine dies if main process crashes.
  + Don't display claim draw dialog when opening game.
  + Fix wrong player sometimes winning when timer expires.
  + Fix various bugs with open/save dialogs and switch to native
    dialogs.
* Tue Apr 24 2018 luc14n0@linuxmail.org
- Update to version 3.29.1:
  + Display special message when en passant is performed.
  + Fix draw being offered improperly when viewing past history.
* Wed Apr 11 2018 luc14n0@linuxmail.org
- Update to version 3.28.1:
  + Updated translations.
- Update URL tag to https://wiki.gnome.org/Apps/Chess: currently
  the Chess' web page.
- Drop:
  + update-desktop-files BuildRequires and suse_update_desktop_file
    macro: they are no longer required anymore.
  + gl and x11 pkgconfig modules BuilRequires: they are not needed
    nor used anymore.
- Add pkgconfig(gio-unix-2.0) BuildRequires to avoid implicit
  dependencies.
* Sun Mar 11 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Nov 17 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Fix gschema installation.
  + Fix SVG images installation.
- Changes from version 3.27.1:
  + Port to Meson build system.
- Add meson BuildRequires and switch configure, make and
  make_install macros to meson, meson_build and meson_install
  following upstream port to Meson Build System.
- Drop intltool BuildRequires: upstream did the Gettext migration
  long ago and deviations are not desired to avoid unexpected
  bugs.
- Add fdupes BuildRequires and its macro for replacement of
  duplicates with links under the data directory.
- Drop libxml2-tools, desktop-file-utils and pkgconfig(glu)
  BuildRequires: no longer needed/used anymore.
- Drop %%glib2_gsettings_schema_requires macro: no longer needed
  since RPM file triggers.
* Sat Sep  9 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Wed Aug 16 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Update po/Makevars.
  + Updated translations.
- Drop obsolete post(un) handling, following macros removed:
  glib2_gsettings_schema_post(un), icon_theme_cache_post(un) and
  desktop_database_post(un).
* Wed Apr 19 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Fix build error with new GLib.
  + Updated translations.
* Wed Mar 22 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Add flatpak manifest.
  + Updated translations.
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 3.23.92.5:
  + Fix game ending too soon when using Fischer/Bronstein clocks.
* Sat Mar 11 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Display claim draw dialog unlimited times per game
    (bgo#765997).
  + Support new fivefold repetition and 75 move draw conditions
    (bgo#766005).
  + Fix preferences dialog being treated as its own window.
  + Fix build with latest Vala.
  + Add OARS content rating metadata.
  + Updated translations.
- Add vala BuildRequires: Build vala support.
* Sun Nov  6 2016 zaitor@opensuse.org
- Update to version 3.22.2:
  + Remove trailing whitespace.
  + Updated translations.
* Wed Sep 21 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Update appdata.
  + Fix style-checker with new libgnome-games-support.
  + Fix valac warnings about static const.
  + Stop using intltool.
  + Remove 3D from desktop file comment.
  + Use namespace instead of class for BitBoard.
  + autogen: Improve style of style checker enablement code.
  + Updated translations.
* Tue Jun 21 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Display an information bar if no chess engine is
    installed.
  + Make build work when srcdir != builddir.
  + Updated translations.
* Sat May  7 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Fix window size growing out of control with GTK+ 3.20.
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Update license.
  + Use AM_DISTCHECK_CONFIGURE_FLAGS.
  + Bump up the license version on source files.
  + Update about dialog.
  + Update copyrights.
  + Require GTK+ 3.19.
  + Update the AppData to spec version 0.7+.
  + Updated translations.
- Change license to GPL-3.0+, following upstreams relicensing.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Updated translations.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 3.19.3:
  + Update doap.
  + Add CECP/UCI specs under doc/ and move PGN spec.
  + Disable selecting pieces after the game is over.
  + Fix autogen to check symlink for style-checker.
  + Add pre-applypatch code style checker hook.
  + Bump up gtk version to 3.16.0.
  + Keep the list-of-modules in alphabetical order.
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Updated translations.
* Sun Oct 25 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + Update obsolete FSF address in translatable string.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Mon Sep 14 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Fix dragging the window after clicking the game view.
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Don't kill a broken chess-engine twice.
  + Reorder pre-conditions on engine_stopped_cb.
  + Fix various resource leaks in chess-engine.
  + Updated translations.
* Sun Jul 19 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Display a warning dialog if no chess engines are installed.
  + Force engines to move after some timeout.
  + Updated translations.
* Fri Jun 26 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Build system improvements.
  + Updated translations.
* Tue May 26 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Fix pgn load with invalid moves behaviour.
  + Update tests.
  + Move guideline checker hook to libgames-support.
* Sun May 10 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Validate input when opening files.
  + Add option to alternate between black and white.
* Sun May 10 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + icon: provide a symbolic variant of the app icon.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Fix crash on invalid clock type in pgn.
  + Fix bad pgn load behaviour.
  + Updated translations.
* Fri Mar 20 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + New pre-commit hook added to check gnome coding guidelines.
  + Updated translations.
* Sun Mar  1 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Do not hammer dconf on resize.
  + Miscellaneous code improvements.
  + Updated translations.
* Sat Feb 21 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + NEW FEATURE: Added support for Fischer and Bronstein clocks.
  + Add copy of PGN spec to the repo.
  + Improving the precision of chess-clock.
  + Miscellaneous code improvements.
  + Updated translations.
* Sat Feb 21 2015 badshah400@gmail.com
- Update to version 3.15.4:
  + Cancel move if promotion type selector is closed.
  + Fix chess timer gets reset to the max allowed on game restarts.
  + Load completed saved games properly.
  + Fix saving a completed game due to timeup saves the timer as
    infinity.
  + Reset the selected piece upon undo.
  + Miscellaneous code improvements.
  + Updated translations.
- Add pkgconfig(glib-2.0), pkgconfig(gio-2.0) and
  pkgconfig(gmodule-2.0) BuildRequires: new verified dependencies.
* Sat Feb 21 2015 zaitor@opensuse.org
- Update to version 3.14.3:
  + Fix chess timer gets reset to the max allowed on game restarts.
  + Load completed saved games properly.
  + Saving a completed game due to timeup saves the timer as
    infinity.
  + Improved the precision of chess-clock.
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Regression: broken timer after Resign -> Keep Playing.
  + Regression: broken timer after Pause -> Unpause.
  + Updated translations.
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Mon Sep 22 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated appdata.
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Fix game ending with 1s left on timer.
  + Updated translations.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Distribute high contrast icon (from gnome-themes-standard).
  + Don't mention GNOME Games in about dialog.
  + Updated translations.
- Build HighContrast icon cache in post/postun.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Remove 3D mode. Goodbye 3D mode.
  + Time control is now a per-player limit, rather than a max
    duration.
  + Fix undo before engine moves.
  + Fix engine desync when browsing history on engine's turn.
  + Do not enable pause action when browsing history.
  + Fix clock unpausing after game is over in rare situations.
  + Return view to present when engine moves.
  + Reword some error messages.
  + Shorten some window subtitles.
  + Add command line warning when engine makes illegal move.
  + Do not try to stop the game twice when an engine error occurs.
  + Ensure new game button is always sensitive when on game over.
  + Update header bar title when using Undo.
  + Workaround Vala signal misfires that could cause a rare crash.
  + Use header bar on promotion dialog.
  + Pause overlay is now transparent (but pieces are hidden).
  + Minor improvements to preferences dialog.
  + Set bigger minimum size for chess board.
  + Miscellaneous code improvements.
  + Updated translations.
* Mon Jun 30 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + The gear menu has been replaced with a Resign button.
  + The Save button has been replaced with a Save As button.
  + Claim Draw action removed. The player is now prompted if a
    claim is possible.
  + Fix build on non-Linux systems.
  + Fix incorrect header bar title after player uses Undo.
  + Fix clock counting down if chess engine reports move while game
    is paused.
  + Fix time labels sometimes resizing as the clock counts down.
  + Disable the new game button if White has not made the first
    move.
  + Add missing mnemonics in the preferences dialog.
  + Add a mnemonic for the New Game button.
  + Use a ratio character, not a colon, in the timers.
  + Fix untranslated strings in the save game dialog.
  + Updated translations.
* Mon Jun 30 2014 zaitor@opensuse.org
- Update to version 3.12.3:
  + Fix desync with chess engines when using undo during the
    engine's turn.
  + Fix desync with chess engine when viewing history during the
    engine's turn.
  + Return view to present if viewing history when engine moves.
  + Fix clock sometimes unpausing after game ends due to desync
    with engine.
  + Fix Pause button sensitivity after the game is over when
    browsing history.
  + Fix New Game button sensitivity if the game ends before the
    first move (possible if there is a problem with the chess
    engine).
  + Workaround Vala signal misfires causing a rare crash when using
    undo after starting very many new games.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Fix build on non-Linux systems.
  + Fix incorrect header bar title after player uses Undo.
  + Fix clock counting down if chess engine reports move while game
    is paused.
  + Fix time labels sometimes resizing as the clock counts down.
  + Disable the new game button if White has not made the first
    move.
  + Fix untranslated strings in the save game dialog.
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Mon Mar 17 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Fix missing 3D mode option (by removing bad check for Wayland).
  + Fix size of some buttons in the header bar.
  + Use correct Play button icon in RTL layouts.
  + Update screenshots and part of user docs text.
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + GNU Chess is now the recommended default chess engine for
    Linux distributions.
  + New difficulty levels for GNU Chess.
  + The engines configuration file has moved from
    SYSCONFDIR/chess-engines.conf to
    SYSCONFDIR/gnome-chess/engines.conf and the original file will
    no longer be read.
  + engines.conf now has a new option, delay-before-move, used to
    set the delay in seconds after a human moves before the engine
    is told to make a move.
  + Many actions previously in the gear menu now live as buttons in
    the header bar.
  + Added extra two seconds of delay before the engine moves for
    most engines.
  + This slows down the game to make it less overwhelming.
  + It is no longer possible to enter 3D mode when using Wayland or
    Mir. Support for these environments will not be added in time
    for 3.10. Use 2D mode instead.
  + The game is now properly paused when the Claim Draw dialog is
    open.
  + Fix color in window subtitle displayed when White is
    checkmated.
  + Shorten the window subtitle displayed when something goes
    wrong.
  + The desktop file has been renamed to gnome-chess.desktop.
  + Updated man page.
  + Updated translations.
- Update the %%suse_update_desktop_file according to upstream
  changes.
* Mon Jan 20 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Redesign: GtkHeaderBar and GtkMenuButton replace the
    GtkToolbar.
  + Remove fullscreen mode.
  + Use symbolic icons in the buttom bar.
  + Add the "linked" style to the navigation buttons.
  + Use a symbolic light bulb in the preferences dialog.
  + Remove extra space between White and Black timers.
  + Don't automatically pause when switching windows or viewing the
    menu.
  + The pause key is now an accelerator for the pause/resume
    action.
  + Show better errors when something goes wrong with the engine.
  + Never claim the engine has died when all is well.
  + Display a message if a human player is in check.
  + Warn user when engine fails to launch.
  + Fix colors of pieces in figurine algebraic notation.
  + Fix critical warnings when starting a new game.
  + Never try to kill the same engine process twice.
  + ChessEngine: fix minor file descriptor leaks.
  + Don't leave an orphaned engine if we crash.
  + About dialog: update website.
  + Updated translations.
* Mon Jan 20 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + New app icon.
  + Replace some deprecated containers.
  + Updated translations.
* Mon Jan 20 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Fix black background in 3D view.
  + Fix Paused overlay displaying upside-down with Black on the
    bottom.
  + Fix too-small left arrow in history controls.
  + Fix a harmless assertion failure.
  + Add missing GTK category to desktop file.
  + Updated translations.
* Mon Jan 20 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Appdata is now translatable.
  + Eliminate deprecated function usage.
  + Updated translations.
* Mon Jan 20 2014 dimstar@opensuse.org
- Update to version 3.10.3:
  + Never autosave over a user's files.
  + Never claim the engine has died when all is well.
  + Fix critical warnings when starting a new game.
  + Fix colors of pieces in figurine algebraic notation.
  + Ensure the chess engine is always killed, even if we crash.
  + Fix minor file descriptor leaks.
  + Update screenshot link in appdata.
  + Fix image in first_move_button.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 9bnc#849913):
  + Fix "Paused" notice displaying upside-down when Black is on the
    bottom.
  + Fix a harmless assertion failure.
  + Updated translations.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1.1:
  + Fix regression causing "Something has gone wrong!" message on
    checkmate.
  + Fix regression causing every opened PGN to be deleted.
* Sun Oct 13 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Player on move is now considered in check for threefold
    repetition.
  + Implement more CECP functionality, making a desync with the
    engine less likely.
  + If an engine's process dies, display a warning instead of
    claiming it resigned.
  + Help: remove Amundsen from list of supported engines.
  + Help: remove the "there are no bugs" page; regrettably, there
    are bugs.
  + Add an appdata file for GNOME Software.
  + Updated translations.
- Drop pkgconfig(sqlite3) BuildRequires: no longer required.
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + New pause game option added.
  + Fix figurine algebraic notation displaying the wrong figures.
  + Store only one game at a time in autosave history.
  + Prompt the user to save the game before opening a new one.
  + Fix viewing arbitrary turns with the history combo box.
  + Fullscreen icon should change to unfullscreen icon when in
    fullscreen view.
  + The game will now display a warning and end the game when an
    engine makes an illegal move, or when a CECP engine claims
    GNOME Chess allowed an illegal move, instead of hanging
    forever.
  + Claim Draw now works again
  - If a draw cannot be claimed, an explanatory dialog is shown.
  - Fix two bugs with threefold repetiton detection.
  - Fix fifty-move rule detection.
  + Preferences
  - Now transient for the main window (not considered separate by
    GNOME Shell).
  - Remove show history option.
  - Reorder some preferences.
  + engines.conf
  - Renamed to chess-engines.conf.
  - Now installed into $sysconfdir instead of
    $(datadir)/gnome-chess.
  - The format for passing UCI options to engines has been
    simplified.
  - New support for adding arguments to be appended to the UCI go
    command.
  - UCI engines should now be much easier.
  - Miscellaneous changes to other engines.
  - Amundsen support dropped due to lack of support for Undo.
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Added support for the Octochess engine.
  + Easier Easy/Normal settings for many engines.
  + Fix AI hang when using Undo against most CECP engines.
  + Fix crash when new game dialog is deleted.
  + Don't include path to opened game in window title.
  + HIG: preferences options should use sentence capitalization.
  + Fix keyboard shortcuts for New/Open/Save/Undo/Fullscreen.
  + Don't start new game if new game dialog is deleted.
  + 3D: bottom-right corner should be white.
  + Preferences: move "opposing player" to the top.
  + Side and difficulty selection should be insensitive in human
    vs. human games.
  + Update About dialog copyright notice.
  + Fix board numbering when Black is on bottom.
  + Some new toolbar items were missing tooltips.
  + Add keyboard shortcuts for previous/next move.
  + 3D: improve alignment of file letters.
  + Autosave: always forget games after they are completed.
  + Remove face-to-face board orientation.
  + Suggest longer game durations.
  + Instruct CECP engines to add randomness to play.
  + Updated translations.
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + Added an application menu.
  + Removed the menubar.
  + Added several items to the toolbar.
  + The toolbar is now mandatory.
  + Fix crash when using Undo while viewing a previous move.
  + Fix crash after completing a timed game where the timer did not
    expire.
  + Fix insanely small load game dialog.
  + Save and load players' time remaining in timed games.
  + Better decide when and when not to autosave a game.
  + King and bishop vs. king and bishop on opposite color is not
    insufficient material.
  + Set a default filename with the .pgn extension for the save
    game dialog.
  + When prompting to save a completed game, use a more natural
    message.
  + After prompting to save before starting a new game, prompt for
    a save location instead of autosaving.
  + Slight improvements to the promotion type selection dialog.
  + "Human" move descriptons now more naturally describe castling.
  + Add a 256x256 icon.
  + Updated translations.
* Mon May 27 2013 zaitor@opensuse.org
- Update to version 3.9.2:
  + Make the computer's pieces uncontrollable.
  + Fix Stockfish engine integration.
  + Fix massive CPU usage after completing a game against an engine
    and starting a new one.
  + Fix AI hang when loading a game where the human was last to
    move.
  + Fix resigning on your opponent's turn causing him to lose (and
    you to win).
  + Fix board numbering showing in 3D view when board numbering is
    disabled.
  + Specify the opposing engine in saved games even if it is the
    default.
  + Each player's clock is now initially set to half the game's
    total duration.
  + The clock now begins counting down only after White's first
    move.
  + The clock now stops counting down once the game is over.
  + Stop the engine immediately when the game ends, not when the
    next game starts.
  + Sensibly set the sensitivity of Smooth Display and Piece Style
    preferences depending on if 3D view is enabled.
  + Improve sensitivity checks for Save As, Undo Move, Resign, and
    Claim Draw.
  + Increase default window width to 700.
  + Update the FSF's address in license notices.
  + Translate "Chess" on the About page.
  + Translation updates.
* Mon Apr 29 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + help: Fix obsolete product of bugzilla.
  + Respect engine args specified in engines.conf.
  + ChessState.get_fen() replaces all knights with kings.
  + Insufficient material fixes.
  + Chess history doesn't work very well.
  + Fix AI hang when Phalanx attempts to promote.
  + Updated translations.
* Sat Mar 30 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
- Changes from version 3.7.92:
  + Rename desktop file back to glchess.desktop.
  + Updated translations.
- Changes from version 3.7.90:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Also obsolete glchess-lang to ease upgrades.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Wed Feb 13 2013 dimstar@opensuse.org
- Initial package, version 3.7.5
